@@ -22,6 +22,9 @@ from up42.jobcollection import JobCollection
 from up42.jobtask import JobTask
 from up42.catalog import Catalog
 from up42.estimation import Estimation
+from up42.storage import Storage
+from up42.asset import Asset
+from up42.order import Order
 from up42.__init__ import (
     authenticate,
     initialize_project,
@@ -29,4 +32,7 @@ from up42.__init__ import (
     initialize_workflow,
     initialize_job,
     initialize_jobtask,
+    initialize_storage,
+    initialize_order,
+    initialize_asset,
 )
