@@ -13,11 +13,7 @@ from .fixtures import (
     auth_mock,
     auth_live,
 )
-from .fixtures import (
-    TOKEN,
-    PROJECT_ID,
-    PROJECT_APIKEY,
-)
+from .fixtures import TOKEN, PROJECT_ID, PROJECT_APIKEY, WORKSPACE_ID
 
 
 def test_auth_kwargs():
@@ -71,6 +67,16 @@ def test_get_token_project_live(auth_live):
     assert hasattr(auth_live, "token")
 
 
+def test_get_workspace(auth_mock):
+    auth_mock._get_workspace()
+    assert auth_mock.workspace_id == WORKSPACE_ID
+
+
+@pytest.mark.live
+def test_get_workspace_live(auth_live):
+    assert hasattr(auth_live, "workspace_id")
+
+
 def test_generate_headers(auth_mock_no_request):
     version = io.open(
         Path(__file__).resolve().parents[1] / "up42/_version.txt", encoding="utf-8"
@@ -115,6 +121,18 @@ def test_request_non200_raises(auth_mock, requests_mock):
     assert "some 403 error message!" in str(e.value)
 
 
+def test_request_non200_raises_error_not_dict(auth_mock, requests_mock):
+    requests_mock.get(
+        url="http://test.com",
+        json={"data": {}, "error": "Not found!"},
+        status_code=403,
+    )
+
+    with pytest.raises(requests.exceptions.RequestException) as e:
+        auth_mock._request(request_type="GET", url="http://test.com")
+    assert "Not found!" in str(e.value)
+
+
 def test_request_with_retry(auth_mock, requests_mock):
     auth_mock.retry = True
     # Retry contains getting a new token, already mocked in fixture.
