@@ -278,6 +278,48 @@ def test_download_result_from_gcs(requests_mock):
         assert not (Path(tempdir) / "output").exists()
 
 
+def test_download_result_from_gcs_zip(requests_mock):
+    cloud_storage_url = "http://clouddownload.api.com/abcdef"
+
+    out_zip = Path(__file__).resolve().parent / "mock_data/result_tif.zip"
+    out_zip_file = open(out_zip, "rb")
+    requests_mock.get(
+        url=cloud_storage_url,
+        content=out_zip_file.read(),
+    )
+    with tempfile.TemporaryDirectory() as tempdir:
+        with open(Path(tempdir) / "dummy.txt", "w") as fp:
+            fp.write("dummy")
+        out_files = download_results_from_gcs(
+            download_url=cloud_storage_url,
+            output_directory=tempdir,
+        )
+
+        for file in out_files:
+            assert Path(file).exists()
+        assert len(out_files) == 2
+        assert not (Path(tempdir) / "output").exists()
+
+
+def test_download_result_from_gcs_not_compressed(requests_mock):
+    cloud_storage_url = "http://clouddownload.api.com/abcdef"
+
+    out_zip = Path(__file__).resolve().parent / "mock_data/aoi_berlin.geojson"
+    out_zip_file = open(out_zip, "rb")
+    requests_mock.get(
+        url=cloud_storage_url,
+        content=out_zip_file.read(),
+    )
+    with tempfile.TemporaryDirectory() as tempdir:
+        with open(Path(tempdir) / "dummy.txt", "w") as fp:
+            fp.write("dummy")
+        with pytest.raises(ValueError):
+            download_results_from_gcs(
+                download_url=cloud_storage_url,
+                output_directory=tempdir,
+            )
+
+
 def test_filter_jobs_on_mode():
     job_json = [{"mode": "DEFAULT"}, {"mode": "DRY_RUN"}]
     r = filter_jobs_on_mode(job_json)
