@@ -6,7 +6,7 @@ import pytest
 import shapely
 
 # pylint: disable=unused-import,wrong-import-order
-from .context import Workflow, Job, JobCollection
+from .context import Workflow, Job, JobCollection, Asset
 from .fixtures import (
     auth_mock,
     auth_live,
@@ -17,6 +17,7 @@ from .fixtures import (
     jobtask_mock,
     project_mock,
     project_mock_max_concurrent_jobs,
+    asset_mock,
 )
 from .fixtures import (
     JOB_ID,
@@ -265,6 +266,28 @@ def test_construct_parameter_order_ids(workflow_mock):
     }
 
 
+def test_construct_parameter_assets(workflow_mock, asset_mock, monkeypatch):
+    parameters = workflow_mock.construct_parameters(assets=[asset_mock])
+    assert isinstance(parameters, dict)
+    assert parameters == {
+        "sobloo-s2-l1c-aoiclipped:1": {"asset_ids": [asset_mock.asset_id]},
+        "tiling:1": {"nodata": "None", "tile_width": 768},
+    }
+
+    parameters = workflow_mock.construct_parameters(assets=[asset_mock, asset_mock])
+    assert isinstance(parameters, dict)
+    assert parameters == {
+        "sobloo-s2-l1c-aoiclipped:1": {
+            "asset_ids": [asset_mock.asset_id, asset_mock.asset_id]
+        },
+        "tiling:1": {"nodata": "None", "tile_width": 768},
+    }
+
+    monkeypatch.setattr(Asset, "source", property(lambda self: "ORDER"))
+    with pytest.raises(ValueError):
+        workflow_mock.construct_parameters(assets=[asset_mock])
+
+
 def test_construct_parameters_parallel(workflow_mock):
     parameters_list = workflow_mock.construct_parameters_parallel(
         geometries=[
@@ -336,7 +359,9 @@ def test_estimate_jobs(workflow_mock, auth_mock, requests_mock):
         f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
         f"{workflow_mock.workflow_id}/tasks"
     )
-    url_workflow_estimation = f"{auth_mock._endpoint()}/estimate/job"
+    url_workflow_estimation = (
+        f"{auth_mock._endpoint()}/projects/{auth_mock.project_id}/estimate/job"
+    )
     requests_mock.get(url=url_workflow_tasks, json=JSON_WORKFLOW_TASKS)
     requests_mock.post(url=url_workflow_estimation, json=JSON_WORKFLOW_ESTIMATION)
 
