@@ -16,6 +16,9 @@ from up42.job import Job
 from up42.jobtask import JobTask
 from up42.jobcollection import JobCollection
 from up42.catalog import Catalog
+from up42.storage import Storage
+from up42.order import Order
+from up42.asset import Asset
 from up42.utils import get_logger
 
 logger = get_logger(__name__, level=logging.INFO)
@@ -130,6 +133,43 @@ def initialize_jobcollection(job_ids: List[str]) -> "JobCollection":
     return jobcollection
 
 
+def initialize_storage() -> "Storage":
+    """
+    Returns a Storage object to list orders and assets.
+    """
+    if _auth is None:
+        raise RuntimeError("Not authenticated, call up42.authenticate() first")
+    return Storage(auth=_auth)
+
+
+def initialize_order(order_id: str) -> "Order":
+    """
+    Returns an Order object (has to exist on UP42).
+
+    Args:
+        order_id: The UP42 order_id
+    """
+    if _auth is None:
+        raise RuntimeError("Not authenticated, call up42.authenticate() first")
+    order = Order(auth=_auth, order_id=order_id)
+    logger.info(f"Initialized {order}")
+    return order
+
+
+def initialize_asset(asset_id: str) -> "Asset":
+    """
+    Returns an Asset object (has to exist on UP42).
+
+    Args:
+        asset_id: The UP42 asset_id
+    """
+    if _auth is None:
+        raise RuntimeError("Not authenticated, call up42.authenticate() first")
+    asset = Asset(auth=_auth, asset_id=asset_id)
+    logger.info(f"Initialized {asset}")
+    return asset
+
+
 def get_blocks(
     block_type=None,
     basic: bool = True,
