@@ -6,6 +6,7 @@ from geojson import FeatureCollection
 
 from up42.auth import Auth
 from up42.job import Job
+from up42.viztools import VizTools
 from up42.tools import Tools
 
 from up42.utils import get_logger, deprecation
@@ -13,7 +14,7 @@ from up42.utils import get_logger, deprecation
 logger = get_logger(__name__)
 
 
-class JobCollection(Tools):
+class JobCollection(VizTools, Tools):
     def __init__(self, auth: Auth, project_id: str, jobs: List[Job]):
         """
         The JobCollection class provides facilities for downloading and merging
@@ -49,7 +50,7 @@ class JobCollection(Tools):
     def get_jobs_info(self) -> Dict[str, Dict]:
         """
         `get_jobs_info` will be deprecated in release 0.13, use
-        [info attribute](jobcollection.md#up42.jobcollection.JobCollection.info) instead.
+        [info attribute](jobcollection-reference.md#up42.jobcollection.JobCollection.info) instead.
         """
         return self.info
 
@@ -65,7 +66,7 @@ class JobCollection(Tools):
     def get_jobs_status(self) -> Dict[str, str]:
         """
         `get_jobs_status` will be deprecated in release 0.13, use
-        [status attribute](jobcollection.md#up42.jobcollection.JobCollection.status) instead.
+        [status attribute](jobcollection-reference.md#up42.jobcollection.JobCollection.status) instead.
         """
         return self.status
 
